summaryrefslogtreecommitdiff
path: root/indra/llrender
diff options
context:
space:
mode:
authorAlexander Gavriliuk <alexandrgproductengine@lindenlab.com>2024-07-05 18:46:30 +0200
committerGuru <alexandrgproductengine@lindenlab.com>2024-07-06 08:38:17 +0200
commit9ddf64c65183960ffed4fe61c5d85e8bacaea030 (patch)
tree27fe44bb1efa81776f40f9c701cc02a5800c1467 /indra/llrender
parent958f7812839160247207c01e78b90f1935022ab3 (diff)
#1931 BugSplat Crash: SecondLifeViewer!LLRenderTarget::release(387)
Diffstat (limited to 'indra/llrender')
-rw-r--r--indra/llrender/llrendertarget.cpp4
-rw-r--r--indra/llrender/llrendertarget.h4
2 files changed, 7 insertions, 1 deletions
diff --git a/indra/llrender/llrendertarget.cpp b/indra/llrender/llrendertarget.cpp
index 60159a0497..410efe9a70 100644
--- a/indra/llrender/llrendertarget.cpp
+++ b/indra/llrender/llrendertarget.cpp
@@ -50,6 +50,7 @@ void check_framebuffer_status()
}
}
+bool LLRenderTarget::sInitFailed = false;
bool LLRenderTarget::sUseFBO = false;
U32 LLRenderTarget::sCurFBO = 0;
@@ -352,6 +353,9 @@ void LLRenderTarget::release()
LL_PROFILE_ZONE_SCOPED_CATEGORY_DISPLAY;
llassert(!isBoundInStack());
+ if (sInitFailed)
+ return;
+
if (mDepth)
{
LLImageGL::deleteTextures(1, &mDepth);
diff --git a/indra/llrender/llrendertarget.h b/indra/llrender/llrendertarget.h
index a1adf93fa1..fc78f059e0 100644
--- a/indra/llrender/llrendertarget.h
+++ b/indra/llrender/llrendertarget.h
@@ -61,7 +61,9 @@
class LLRenderTarget
{
public:
- //whether or not to use FBO implementation
+ // Whether app initialization failed
+ static bool sInitFailed;
+ // Whether or not to use FBO implementation
static bool sUseFBO;
static U32 sBytesAllocated;
static U32 sCurFBO;